@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2012 Red Hat, Inc.
+ * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -670,8 +670,8 @@ static xmlNodePtr osinfo_install_script_generate_entity_xml(OsinfoInstallScript
         goto error;
     }
 
-    if (!(data = xmlNewDocNode(NULL, NULL, (const xmlChar*)"id",
-                               (const xmlChar*)osinfo_entity_get_id(entity)))) {
+    if (!(data = xmlNewDocRawNode(NULL, NULL, (const xmlChar*)"id",
+                                  (const xmlChar*)osinfo_entity_get_id(entity)))) {
         xmlErrorPtr err = xmlGetLastError();
         g_set_error(error, 0, 0, _("Unable to create XML node 'id': '%s'"),
                     err ? err->message : "");
@@ -698,8 +698,8 @@ static xmlNodePtr osinfo_install_script_generate_entity_xml(OsinfoInstallScript
 
         tmp2 = values;
         while (tmp2) {
-            if (!(data = xmlNewDocNode(NULL, NULL, (const xmlChar*)tmp1->data,
-                                       (const xmlChar*)tmp2->data))) {
+            if (!(data = xmlNewDocRawNode(NULL, NULL, (const xmlChar*)tmp1->data,
+                                          (const xmlChar*)tmp2->data))) {
                 xmlErrorPtr err = xmlGetLastError();
                 g_set_error(error, 0, 0, _("Unable to create XML node '%s': '%s'"),
                             (const gchar *)tmp1->data, err ? err->message : "");
@@ -1309,6 +1309,23 @@ int osinfo_install_script_get_post_install_drivers_signing_req(OsinfoInstallScri
          OSINFO_DEVICE_DRIVER_SIGNING_REQ_NONE);
 }
 
+/**
+ * osinfo_install_script_get_injection_methods:
+ * @script: the install script
+ *
+ * Retrieve the supported method to inject the script in to the installation process.
+ *
+ * Returns: (type OsinfoInstallScriptInjectionMethod): bitwise-or of
+ * supported methods for install script injection.
+ */
+unsigned int osinfo_install_script_get_injection_methods(OsinfoInstallScript *script)
+{
+    return osinfo_entity_get_param_value_int64_with_default
+        (OSINFO_ENTITY(script),
+         OSINFO_INSTALL_SCRIPT_PROP_INJECTION_METHOD,
+         0);
+}
+
 
 /*
  * Local variables:
